require "import"
import "android.speech.tts.TextToSpeech"
import "android.speech.RecognizerIntent"
import "android.content.Intent"
import "android.os.Handler"
import "android.os.Looper"
import "android.provider.Settings"
import "android.widget.Toast"

local tts
local handler = Handler(Looper.getMainLooper())
local isRecording = false

function initTTS()
    tts = TextToSpeech(activity, TextToSpeech.OnInitListener {
        onInit = function(status)
            if status == TextToSpeech.SUCCESS then
                startVoiceRecognition()
            else
                print("Error initializing TTS.")
            end
        end
    })
end

function setBrightness(brightnessLevel)
    local resolver = activity.getContentResolver()
    Settings.System.putInt(resolver, Settings.System.SCREEN_BRIGHTNESS_MODE, Settings.System.SCREEN_BRIGHTNESS_MODE_MANUAL)
    Settings.System.putInt(resolver, Settings.System.SCREEN_BRIGHTNESS, brightnessLevel)
    local layoutParams = activity.getWindow().getAttributes()
    layoutParams.screenBrightness = brightnessLevel / 255
    activity.getWindow().setAttributes(layoutParams)
end

function getCurrentBrightness()
    local resolver = activity.getContentResolver()
    return Settings.System.getInt(resolver, Settings.System.SCREEN_BRIGHTNESS)
end

function announceBrightness()
    local currentBrightness = getCurrentBrightness()
    local brightnessPercent = math.floor(currentBrightness / 255 * 100 + 0.5) -- Rotunjire corectă
    Toast.makeText(activity, "Acum luminozitatea curentă este " .. brightnessPercent .. " procente.", Toast.LENGTH_SHORT).show()
    tts.speak("Acum luminozitatea curentă este " .. brightnessPercent .. " procente.", TextToSpeech.QUEUE_FLUSH, nil, nil)
end

function processVoiceResult(result)
    local number = tonumber(result)
    if number and number >= 1 and number <= 100 then
        local brightness = math.floor(number / 100 * 255 + 0.5) -- Conversie precisă cu rotunjire
        setBrightness(brightness)
        announceBrightness()
    else
        Toast.makeText(activity, "Număr invalid. Te rog să spui un număr între 1 și 100.", Toast.LENGTH_SHORT).show()
        tts.speak("Număr invalid. Te rog să spui un număr între 1 și 100.", TextToSpeech.QUEUE_FLUSH, nil, nil)
    end
    goBack()
end

function goBack()
    activity.finish()
end

function startVoiceRecognition()
    if isRecording then return end
    isRecording = true

    Toast.makeText(activity, "Dictați un număr pentru modificarea luminozității.", Toast.LENGTH_SHORT).show()
    tts.speak("Dictați un număr pentru modificarea luminozității.", TextToSpeech.QUEUE_FLUSH, nil, nil)

    handler.postDelayed(function()
        local intent = Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH)
        intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE_MODEL, RecognizerIntent.LANGUAGE_MODEL_FREE_FORM)
        intent.putExtra(RecognizerIntent.EXTRA_PROMPT, "Spune un număr între 1 și 100 pentru a ajusta luminozitatea.")
        activity.startActivityForResult(intent, 123)
    end, 2200)
end

function onActivityResult(requestCode, resultCode, data)
    if requestCode == 123 then
        isRecording = false
        if resultCode == -1 then
            local results = data.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS)
            if results and not results.isEmpty() then
                processVoiceResult(results.get(0))
            else
                Toast.makeText(activity, "Nu am înțeles. Încearcă din nou.", Toast.LENGTH_SHORT).show()
                tts.speak("Nu am înțeles. Încearcă din nou.", TextToSpeech.QUEUE_FLUSH, nil, nil)
                goBack()
            end
        else
            Toast.makeText(activity, "Recunoașterea vocală a fost anulată.", Toast.LENGTH_SHORT).show()
            tts.speak("Recunoașterea vocală a fost anulată.", TextToSpeech.QUEUE_FLUSH, nil, nil)
            goBack()
        end
    end
end

initTTS()
